#  Copyright 2022 Red Hat, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

from dataclasses import dataclass

DEFAULT_SHUTDOWN_DELAY = 60.0


@dataclass(frozen=True)
class Shutdown:
    message: str = "Not specified"
    delay: float = DEFAULT_SHUTDOWN_DELAY
    kind: str = "graceful"
    source_plugin: str = ""
